
![image](https://github.com/user-attachments/assets/7d03da7d-f2e2-4dac-b2da-1c73d1dc9949)
<div align="center">
    <h2>PAYHERO PYTHON SDK </h2>
</div>
<p align="center">
    <em>A Python wrapper for interacting with the PayHero API </em>
</p>

<p align="center">
<a href="https://pypi.org/project/py-payhero" target="_blank">
    <img src="https://img.shields.io/pypi/v/py-payhero?color=%2334D058&label=pypi%20package" alt="Package version">
</a>
<a href="https://pypi.org/project/py-payhero" target="_blank">
    <img src="https://img.shields.io/pypi/pyversions/p.svg?color=%2334D058" alt="Supported Python versions">
</a>
</p>


---

**Documentation**: <a href="https://google.com" target="_blank">https://fast.m</a>

**Source Code**: <a href="https://github.com/njeru-codes/PayHero-API-SDK-" target="_blank">https://github.com/njeru-codes/PayHero-API-SDK-</a>

---

py-payhero is a lightweight python sdk wrapper for interacting with payhero APIs.
features:
  - list 1
  - feature 2

### installation
```bash
  pip install py-payhero
```

### usage 
`for detailed usage of this package head over to documentation page`
```python
  from PayHero import API

  app = API("username", "password")

  service_balance = app.get_service_balance()
  

```

### Contributing
Contributions are welcome! Please follow these steps:
- Fork the repository.
- Create a new branch (git checkout -b feature-branch).
- Make your changes and commit them (git commit -m 'Add new feature').
- Push to the branch (git push origin feature-branch).
- Create a pull request
